# slmd - Sort lists in Markdown

version_info = (0, 1, 1)

__version__ = VERSION = '.'.join(map(str, version_info))
__project__ = PROJECT = 'mdls'
__author__ = AUTHOR = "Park Hyunwoo <ez.amiryo@gmail.com>"


from .slmd import sort, sort_string
